// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef MESSAGEVIEWER_VERSION_H
#define MESSAGEVIEWER_VERSION_H

#define MESSAGEVIEWER_VERSION_STRING "6.7.80"
#define MESSAGEVIEWER_VERSION_MAJOR 6
#define MESSAGEVIEWER_VERSION_MINOR 7
#define MESSAGEVIEWER_VERSION_PATCH 80
#define MESSAGEVIEWER_VERSION ((6<<16)|(7<<8)|(80))

#endif
