
#ifndef TEMPLATEPARSER_EXPORT_H
#define TEMPLATEPARSER_EXPORT_H

#ifdef TEMPLATEPARSER_STATIC_DEFINE
#  define TEMPLATEPARSER_EXPORT
#  define TEMPLATEPARSER_NO_EXPORT
#else
#  ifndef TEMPLATEPARSER_EXPORT
#    ifdef KPim6TemplateParser_EXPORTS
        /* We are building this library */
#      define TEMPLATEPARSER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEMPLATEPARSER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEMPLATEPARSER_NO_EXPORT
#    define TEMPLATEPARSER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEMPLATEPARSER_DECL_DEPRECATED
#  define TEMPLATEPARSER_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEMPLATEPARSER_DECL_DEPRECATED_EXPORT
#  define TEMPLATEPARSER_DECL_DEPRECATED_EXPORT TEMPLATEPARSER_EXPORT TEMPLATEPARSER_DECL_DEPRECATED
#endif

#ifndef TEMPLATEPARSER_DECL_DEPRECATED_NO_EXPORT
#  define TEMPLATEPARSER_DECL_DEPRECATED_NO_EXPORT TEMPLATEPARSER_NO_EXPORT TEMPLATEPARSER_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEMPLATEPARSER_NO_DEPRECATED
#    define TEMPLATEPARSER_NO_DEPRECATED
#  endif
#endif
#include <templateparser_version.h>

#define TEMPLATEPARSER_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEMPLATEPARSER_NO_DEPRECATED)
#  undef TEMPLATEPARSER_DEPRECATED
#  define TEMPLATEPARSER_DEPRECATED_EXPORT TEMPLATEPARSER_EXPORT
#  define TEMPLATEPARSER_DEPRECATED_NO_EXPORT TEMPLATEPARSER_NO_EXPORT
#elif defined(TEMPLATEPARSER_NO_DEPRECATED_WARNINGS)
#  define TEMPLATEPARSER_DEPRECATED
#  define TEMPLATEPARSER_DEPRECATED_EXPORT TEMPLATEPARSER_EXPORT
#  define TEMPLATEPARSER_DEPRECATED_NO_EXPORT TEMPLATEPARSER_NO_EXPORT
#else
#  define TEMPLATEPARSER_DEPRECATED TEMPLATEPARSER_DECL_DEPRECATED
#  define TEMPLATEPARSER_DEPRECATED_EXPORT TEMPLATEPARSER_DECL_DEPRECATED_EXPORT
#  define TEMPLATEPARSER_DEPRECATED_NO_EXPORT TEMPLATEPARSER_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEMPLATEPARSER_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEMPLATEPARSER_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEMPLATEPARSER_NO_DEPRECATED
#  define TEMPLATEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT TEMPLATEPARSER_VERSION
#endif
#ifdef TEMPLATEPARSER_NO_DEPRECATED_WARNINGS
#  define TEMPLATEPARSER_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEMPLATEPARSER_DEPRECATED_WARNINGS_SINCE
#  ifdef TEMPLATEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEMPLATEPARSER_DEPRECATED_WARNINGS_SINCE TEMPLATEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEMPLATEPARSER_DEPRECATED_WARNINGS_SINCE TEMPLATEPARSER_VERSION
#  endif
#endif

#ifndef TEMPLATEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEMPLATEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef TEMPLATEPARSER_DEPRECATED
#  define TEMPLATEPARSER_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEMPLATEPARSER_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEMPLATEPARSER_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEMPLATEPARSER_EXPORT_H */
