/*
   SPDX-FileCopyrightText: 2020 Daniel Vrátil <dvratil@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#include "messagecomposer_export.h"

namespace MessageComposer
{
namespace FollowUpReminder
{
/*!
 */
[[nodiscard]] MESSAGECOMPOSER_EXPORT bool isAvailableAndEnabled();
}
}
