body {
    margin: 0;
    padding: 0;
}
div#headerbox {
    border-radius: 3px;
    border-bottom: 1px solid rgb(190, 190, 190);
    color: rgb(100, 100, 100) !important;
    overflow: auto;
    padding: 5px 20px;
}
div#headerbox table.outer {
    display: inline;
    position: fixed !important;
    top: -1px;
    left: -1px;
    bottom: -1px;
    right: 0px;
    border: none !important;
    table-collapse: collapse;
}
div#headerbox div#subject {
    color: rgb(100, 100, 100) !important;
    font-size: 22px;
    font-weight: normal;
    line-height: 24px;
    padding-bottom: 5px;
    padding-top: 5px;
}
div#headerbox div#photo {
    float: left;
    margin: 5px;
}
div#headerbox div.table {
    display: table;
    padding-right: 12px;
    padding-top: 6px;
}
div#headerbox div.row {
    display: table-row;
}
div#headerbox div.headerleft {
    display: table-cell;
    padding: 0.1em 1em;
}
div#headerbox div.headerright {
    display: table-cell;
    font-weight: bold;
    padding: 0.1em;
}
div#headerbox div.nowrap {
    white-space: pre; /* this will avoid line breaks*/
}
div#headerbox div.date {
    color: rgb(120, 125, 129) !important;
}
div#headerbox .actiontable {
   display: table;
   width: 100%;
}
div#headerbox div.actionrowtable {
   display:table-row;
}
div#headerbox div.theactioncell {
    display: table-cell;
    padding: 0px 2px; /* just some padding, if needed*/
    white-space: pre; /* this will avoid line breaks*/
}
div#headerbox div.theactionbigcell{
    display: table-cell;
    width: 100%; /* this will shrink other cells */
}

#kmailContent {
    clear: both;
    margin-top: 10px;
    padding: 20px;
}
